@@ -224,26 +224,14 @@ class SafeTx:
         """
         :return: Web3 contract tx prepared for `call`, `transact` or `buildTransaction`
         """
-        print(
-            self.to,
-            self.value,
-            self.data,
-            self.operation,
-            self.safe_tx_gas,
-            self.base_gas,
-            self.gas_price,
-            self.gas_token,
-            self.refund_receiver,
-            self.signatures
-        )
         return self.contract.functions.execTransaction(
             self.to,
             self.value,
             self.data,
             self.operation,
-            self.safe_tx_gas,
-            self.base_gas,
-            self.gas_price,
+            0,
+            0,
+            0,
             self.gas_token,
             self.refund_receiver,
             self.signatures,
